@@ -1,3 +1,3 @@
 # flake8: noqa
 from .version import __version__
-from .fig import FigTransformer
\ No newline at end of file
+from .converter import Converter
\ No newline at end of file
